==> libc-4.7.6.tar.gz: libc/sysdeps/linux/i386/math/__infnan.c <==
/* Copyright (C) 1991, 1992 Free Software Foundation, Inc.
This file is part of the GNU C Library.

The GNU C Library is free software; you can redistribute it and/or
modify it under the terms of the GNU Library General Public License as
published by the Free Software Foundation; either version 2 of the
License, or (at your option) any later version.

The GNU C Library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Library General Public License for more details.

You should have received a copy of the GNU Library General Public
License along with the GNU C Library; see the file COPYING.LIB.  If
not, write to the Free Software Foundation, Inc., 675 Mass Ave,
Cambridge, MA 02139, USA.  */

#include <ansidecl.h>
#include <errno.h>
#include <math.h>
#include <float.h>
#include "ieee754.h"

/* Deal with an infinite or NaN result.
   If ERROR is ERANGE, result is +Inf;
   if ERROR is - ERANGE, result is -Inf;
   otherwise result is NaN.
   This will set `errno' to either ERANGE or EDOM,
   and may return an infinity or NaN, or may do something else.  */
double
DEFUN(__infnan, (error), int error)
{
  switch (error)
    {
    case ERANGE:
      errno = ERANGE;
      return HUGE_VAL;

    case - ERANGE:
      errno = ERANGE;
      return - HUGE_VAL;

    default:
      errno = EDOM;
#ifdef _SNAN
      return _SNAN;
#else
      return NAN;
#endif
    }
}

#include <gnu-stabs.h>
#ifdef weak_alias
weak_alias (__infnan, infnan);
#endif

==> libc-5.4.7.tar.gz: libc/sysdeps/linux/i386/math/__infnan.c <==
/* Copyright (C) 1991, 1992 Free Software Foundation, Inc.
This file is part of the GNU C Library.

The GNU C Library is free software; you can redistribute it and/or
modify it under the terms of the GNU Library General Public License as
published by the Free Software Foundation; either version 2 of the
License, or (at your option) any later version.

The GNU C Library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Library General Public License for more details.

You should have received a copy of the GNU Library General Public
License along with the GNU C Library; see the file COPYING.LIB.  If
not, write to the Free Software Foundation, Inc., 675 Mass Ave,
Cambridge, MA 02139, USA.  */

#include <ansidecl.h>
#include <errno.h>
#include <math.h>
#include <float.h>
#include "ieee754.h"
#if defined(__i386__)
#include <fpu_control.h>
#include <signal.h>
#endif /*  defined(__i386__) */

/* Deal with an infinite or NaN result.
   If ERROR is ERANGE, result is +Inf;
   if ERROR is - ERANGE, result is -Inf;
   otherwise result is NaN.
   This will set `errno' to either ERANGE or EDOM,
   and may return an infinity or NaN, or may do something else.  */
double
DEFUN(__infnan, (error), int error)
{
  switch (error)
    {
    case ERANGE:
      errno = ERANGE;
#if defined(__i386__)
      if (!(__getfpucw() & _FPU_MASK_OM))
	(void) raise(SIGFPE);
#endif /* defined(__i386__) */
      return HUGE_VAL;

    case - ERANGE:
      errno = ERANGE;
#if defined(__i386__)
      if (!(__getfpucw() & _FPU_MASK_OM))
	(void) raise(SIGFPE);
#endif /* defined(__i386__) */
      return - HUGE_VAL;

    default:
      errno = EDOM;
#if defined(__i386__)
      if (!(__getfpucw() & _FPU_MASK_IM))
	(void) raise(SIGFPE);
#endif /* defined(__i386__) */
#ifdef _QNAN
      return _QNAN;
#else
      return NAN;
#endif
    }
}

#include <gnu-stabs.h>
#ifdef weak_alias
weak_alias (__infnan, infnan);
#endif
